@@ -32,13 +32,10 @@ public class EndJudgment extends PriorityJudgment {
 	/**
 	 * 終了状態を判定パターンに当てはめて判定します。
 	 * 
-	 * @param stausList 終了状態の配列
+	 * @param statusList 終了状態の配列
 	 * @return 終了状態
-	 * 
-	 * @see com.clustercontrol.bean.PriorityConstant
-	 * @see com.clustercontrol.bean.EndStatusConstant
 	 */
-	public static Integer judgment(ArrayList stausList) {
+	public static Integer judgment(ArrayList<Integer> statusList) {
 		Integer priority = null;
 		Integer endStatus = null;
 		boolean normal = false;
@@ -46,86 +43,58 @@ public class EndJudgment extends PriorityJudgment {
 		boolean warning = false;
 		boolean unknown = false;
 
-		for(int i =0; i < stausList.size(); i++){
-			Integer status = (Integer)stausList.get(i);
-
-			if(status.intValue() == EndStatusConstant.TYPE_NORMAL){
+		for(Integer status : statusList) {
+			if(status == EndStatusConstant.TYPE_NORMAL){
 				normal = true;
-			}
-			else if(status.intValue() == EndStatusConstant.TYPE_WARNING){
+			}else if(status == EndStatusConstant.TYPE_WARNING){
 				warning = true;
-			}
-			else if(status.intValue() == EndStatusConstant.TYPE_ABNORMAL){
+			}else if(status == EndStatusConstant.TYPE_ABNORMAL){
 				abnormal = true;
 			}
 		}
 
+		// 重要度を算出
 		if(normal && !warning && !abnormal && !unknown){
 			// 　　　　    正常 | 警告 | 異常 | 不明
 			// パターン 1: ○　 | ×　 | ×　 | ×
 			priority = m_patternMap.get(PATTERN_1);
-		}
-		else if(normal && warning && !abnormal && !unknown){
+		}else if(normal && warning && !abnormal && !unknown){
 			// 　　　　    正常 | 警告 | 異常 | 不明
 			// パターン 3: ○　 | ○　 | ×　 | ×
 			priority = m_patternMap.get(PATTERN_3);
-		}
-		else if(!normal && warning && !abnormal && !unknown){
+		}else if(!normal && warning && !abnormal && !unknown){
 			// 　　　　    正常 | 警告 | 異常 | 不明
 			// パターン 5: ×　 | ○　 | ×　 | ×
 			priority = m_patternMap.get(PATTERN_5);
-		}
-		else if(normal && !warning && abnormal && !unknown){
+		}else if(normal && !warning && abnormal && !unknown){
 			// 　　　　    正常 | 警告 | 異常 | 不明
 			// パターン 7: ○　 | ×　 | ○　 | ×
 			priority = m_patternMap.get(PATTERN_7);
-		}
-		else if(normal && warning && abnormal && !unknown){
+		}else if(normal && warning && abnormal && !unknown){
 			// 　　　　    正常 | 警告 | 異常 | 不明
 			// パターン 9: ○　 | ○　 | ○　 | ×
 			priority = m_patternMap.get(PATTERN_9);
-		}
-		else if(!normal && warning && abnormal && !unknown){
+		}else if(!normal && warning && abnormal && !unknown){
 			// 　　　　    正常 | 警告 | 異常 | 不明
 			// パターン11: ×　 | ○　 | ○　 | ×
 			priority = m_patternMap.get(PATTERN_11);
-		}
-		else if(!normal && !warning && abnormal && !unknown){
+		}else if(!normal && !warning && abnormal && !unknown){
 			// 　　　　    正常 | 警告 | 異常 | 不明
 			// パターン13: ×　 | ×　 | ○　 | ×
 			priority = m_patternMap.get(PATTERN_13);
-		}
-		else{
+		}else{
 			return null;
 		}
 
-		//重要度から終了状態に変換
-		endStatus = changePriorityToEndStatus(priority);
-
+		// 重要度から終了状態に変換
+		if(priority == PriorityConstant.TYPE_INFO){
+			endStatus = EndStatusConstant.TYPE_NORMAL;
+		}else if(priority == PriorityConstant.TYPE_WARNING){
+			endStatus = EndStatusConstant.TYPE_WARNING;
+		}else if(priority == PriorityConstant.TYPE_CRITICAL){
+			endStatus = EndStatusConstant.TYPE_ABNORMAL;
+		}
 		return endStatus;
 	}
 
-	/**
-	 * 重要度から終了状態に変換します。
-	 * 
-	 * @param priority 重要度
-	 * @return 終了状態
-	 * 
-	 * @see com.clustercontrol.bean.PriorityConstant
-	 * @see com.clustercontrol.bean.EndStatusConstant
-	 */
-	private static Integer changePriorityToEndStatus(Integer priority) {
-		if(priority.intValue() == PriorityConstant.TYPE_INFO){
-			return Integer.valueOf(EndStatusConstant.TYPE_NORMAL);
-		}
-		else if(priority.intValue() == PriorityConstant.TYPE_WARNING){
-			return Integer.valueOf(EndStatusConstant.TYPE_WARNING);
-		}
-		else if(priority.intValue() == PriorityConstant.TYPE_CRITICAL){
-			return Integer.valueOf(EndStatusConstant.TYPE_ABNORMAL);
-		}
-		else {
-			return null;
-		}
-	}
 }
