@@ -15,28 +15,22 @@ GNU General Public License for more details.
 
 package com.clustercontrol.performance.monitor.factory;
 
-import java.util.Collection;
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
+import java.util.List;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.MonitorNotFound;
-import com.clustercontrol.fault.NotifyNotFound;
-import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
-import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
-
 import com.clustercontrol.monitor.run.bean.MonitorInfo;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoUtil;
 import com.clustercontrol.monitor.run.factory.SelectMonitor;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
+import com.clustercontrol.notify.session.NotifyControllerBean;
 import com.clustercontrol.performance.monitor.bean.PerfCheckInfo;
-import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoUtil;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
+import com.clustercontrol.performance.monitor.model.MonitorPerfInfoEntity;
+import com.clustercontrol.performance.monitor.util.QueryUtil;
+import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
@@ -54,18 +48,19 @@ public class SelectMonitorPerformance extends SelectMonitor{
 	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
 	 */
 	@Override
-	protected PerfCheckInfo getPerfCheckInfo() throws FinderException, NamingException{
+	protected PerfCheckInfo getPerfCheckInfo() throws MonitorNotFound {
+
 		m_log.debug("getPerfCheckInfo() monitorId = " + m_monitorId);
 
 		// リソース監視情報を取得
-		MonitorPerfInfoLocal perfLocal = MonitorPerfInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+		MonitorPerfInfoEntity entity = QueryUtil.getMonitorPerfInfoPK(m_monitorId);
 
 		PerfCheckInfo perfCheck = new PerfCheckInfo();
 		perfCheck.setMonitorTypeId(m_monitorTypeId);
 		perfCheck.setMonitorId(m_monitorId);
-		perfCheck.setItemCode(perfLocal.getItemCode());
-		perfCheck.setDeviceDisplayName(perfLocal.getDeviceDisplayName());
-		perfCheck.setBreakdownFlg(perfLocal.getBreakdownFlg());
+		perfCheck.setItemCode(entity.getItemCode());
+		perfCheck.setDeviceDisplayName(entity.getDeviceDisplayName());
+		perfCheck.setBreakdownFlg(entity.getBreakdownFlg());
 
 		return perfCheck;
 	}
@@ -78,14 +73,12 @@ public class SelectMonitorPerformance extends SelectMonitor{
 	 * @param monitorId 監視項目ID
 	 * @param isGetAll 全監視情報取得フラグ
 	 * @return MonitorInfo
-	 * @throws CreateException
-	 * @throws NamingException
-	 * @throws HinemosUnknown
-	 * @throws NotifyNotFound
 	 * @throws MonitorNotFound
+	 * @throws InvalidRole
+	 * @throws HinemosUnknown
 	 */
 	@Override
-	public MonitorInfo getMonitor(String monitorTypeId, String monitorId) throws CreateException, NamingException, NotifyNotFound, HinemosUnknown, MonitorNotFound {
+	public MonitorInfo getMonitor(String monitorTypeId, String monitorId) throws MonitorNotFound, InvalidRole, HinemosUnknown {
 		m_log.debug("getMonitor() monitorTypeId = " + monitorTypeId + ", monitorId = " + monitorId);
 
 		m_monitorTypeId = monitorTypeId;
@@ -95,16 +88,14 @@ public class SelectMonitorPerformance extends SelectMonitor{
 		try
 		{
 			// 監視情報を取得
-			m_monitor = MonitorInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+			m_monitor = com.clustercontrol.monitor.run.util.QueryUtil.getMonitorInfoPK_NONE(m_monitorId);
 
 			// スコープの取得
-			RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
-			String facilityPath = repository.getFacilityPath(m_monitor.getFacilityId(), null);
-			NotifyControllerLocal nc = NotifyControllerUtil.getLocalHome().create();
+			String facilityPath = new RepositoryControllerBean().getFacilityPath(m_monitor.getFacilityId(), null);
 
 
 			//通知情報の取得
-			Collection notifyId = nc.getNotifyRelation(m_monitor.getNotifyGroupId());
+			List<NotifyRelationInfo> notifyId = new NotifyControllerBean().getNotifyRelation(m_monitor.getNotifyGroupId());
 
 			bean = new MonitorInfo(
 					m_monitor.getApplication(),
@@ -127,6 +118,7 @@ public class SelectMonitorPerformance extends SelectMonitor{
 									m_monitor.getCollectorFlg(),
 									m_monitor.getItemName(),
 									m_monitor.getMeasure(),
+									m_monitor.getOwnerRoleId(),
 									getNumericValueInfo(),
 									getStringValueInfo(),
 									getTruthValueInfo(),
@@ -134,6 +126,7 @@ public class SelectMonitorPerformance extends SelectMonitor{
 									getHttpCheckInfo(),
 									getPerfCheckInfo(),
 									getPingCheckInfo(),
+									getPluginCheckInfo(),
 									getPortCheckInfo(),
 									getProcessCheckInfo(),
 									getSnmpCheckInfo(),
@@ -141,19 +134,17 @@ public class SelectMonitorPerformance extends SelectMonitor{
 									getTrapCheckInfo(),
 									getCommandCheckInfo(),
 									getLogfileCheckInfo(),
-									getWinServiceCheckInfo());
+									getWinServiceCheckInfo(),
+									getWinEventCheckInfo());
 
-		} catch (CreateException e) {
-			outputLog(e, "getMonitor()", "010");
-			m_log.warn("getMonitor()", e);
+		} catch (MonitorNotFound e) {
+			outputLog("010");
 			throw e;
-		} catch (FinderException e) {
-			outputLog(e, "getMonitor()", "010");
-			m_log.warn("getMonitor()", e);
-			throw new MonitorNotFound(e.getMessage(), e);
-		} catch (NamingException e) {
-			outputLog(e, "getMonitor()", "010");
-			m_log.warn("getMonitor()", e);
+		} catch (InvalidRole e) {
+			outputLog("010");
+			throw e;
+		} catch (HinemosUnknown e) {
+			outputLog("010");
 			throw e;
 		}
 
@@ -163,12 +154,11 @@ public class SelectMonitorPerformance extends SelectMonitor{
 	/**
 	 * アプリケーションログにログを出力
 	 * 
-	 * @param e 例外
+	 * @param index アプリケーションログのインデックス
 	 */
-	private void outputLog(Exception e, String method, String index) {
+	private void outputLog(String index) {
 		AplLogger apllog = new AplLogger("PERF", "perf");
 		String[] args = {m_monitorTypeId, m_monitorId };
 		apllog.put("SYS", index, args);
-		m_log.debug(method + ":" + e.getMessage());
 	}
 }
