@@ -17,30 +17,28 @@ package com.clustercontrol.performance.operator;
 
 import java.math.BigInteger;
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstData;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstPK;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstUtil;
+import com.clustercontrol.fault.CollectorNotFound;
+import com.clustercontrol.performance.monitor.entity.CollectorPollingMstData;
+import com.clustercontrol.performance.monitor.model.CollectorPollingMstEntity;
+import com.clustercontrol.performance.monitor.util.QueryUtil;
 import com.clustercontrol.poller.bean.PollerProtocolConstant;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.TableEntry;
-import com.clustercontrol.util.apllog.AplLogger;
 
 abstract public class Operator {
 	private static Log m_log = LogFactory.getLog( Operator.class );
 
+	// 計算式の文字列
+	private String expression;
+
 	// 生成直後に初期化する項目
 	private String collectMethod;
 	private String platformId;
@@ -63,7 +61,7 @@ abstract public class Operator {
 
 	public abstract double calc() throws CollectedDataNotFoundException, InvalidValueException;
 
-	protected void setDataTable(DataTable currentTable, DataTable previousTable){
+	private void setDataTable(DataTable currentTable, DataTable previousTable){
 		this.currentTable = currentTable;
 		this.previousTable = previousTable;
 	}
@@ -76,7 +74,7 @@ abstract public class Operator {
 	 * @throws InvalidValueException
 	 */
 	protected double getCurrentMibValue(String variable)
-	throws CollectedDataNotFoundException, InvalidValueException {
+			throws CollectedDataNotFoundException, InvalidValueException {
 		return getValue(variable, getCurrentTable());
 	}
 
@@ -88,50 +86,10 @@ abstract public class Operator {
 	 * @throws InvalidValueException
 	 */
 	protected double getPreviousMibValue(String variable)
-	throws CollectedDataNotFoundException, InvalidValueException{
+			throws CollectedDataNotFoundException, InvalidValueException{
 		return getValue(variable, getPreviousTable());
 	}
 
-	/**
-	 * 全変数の直近収集値の合計値を取得します
-	 * @return 合計値
-	 * @throws CollectedDataNotFoundException
-	 * @throws InvalidValueException
-	 */
-	protected double getCurrentMibValueTotal()
-	throws CollectedDataNotFoundException, InvalidValueException{
-		Iterator<String> itr = getVariables().iterator();
-
-		double total = 0;
-		while(itr.hasNext()){
-			String variable = itr.next();
-
-			total = total + getCurrentMibValue(variable);
-		}
-
-		return total;
-	}
-
-	/**
-	 * 全変数の前回収集値の合計値を取得します
-	 * @return 合計値
-	 * @throws CollectedDataNotFoundException
-	 * @throws InvalidValueException
-	 */
-	protected double getPreviousMibValueTotal()
-	throws CollectedDataNotFoundException, InvalidValueException{
-		Iterator<String> itr = getVariables().iterator();
-
-		double total = 0;
-		while(itr.hasNext()){
-			String variable = itr.next();
-
-			total = total + getPreviousMibValue(variable);
-		}
-
-		return total;
-	}
-
 	/**
 	 * 前回収集時からの差分を取得します。
 	 * entryKeyの最後の一文字が"*"の場合は、差分の合計を求めます（合計の差分ではない）。
@@ -142,7 +100,7 @@ abstract public class Operator {
 	 * @throws InvalidValueException
 	 */
 	protected double getDifferenceValue(String variable)
-	throws CollectedDataNotFoundException, InvalidValueException{
+			throws CollectedDataNotFoundException, InvalidValueException{
 		if(m_log.isDebugEnabled()){
 			m_log.debug("getDifferenceValue() variable : " + variable);
 		}
@@ -245,18 +203,22 @@ abstract public class Operator {
 				} catch (CollectedDataNotFoundException e) {
 					throw e;
 				} catch (Exception e) {
-					m_log.error("getDifferenceValue() Unknown Error", e);
+					m_log.warn("getDifferenceValue() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				}
 
 				try {
 					return getMibValueDiff(data, currentTable, previousTable,
 							PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget + currentIndex),
 							PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget + previousIndex));
-				}
-				catch (InvalidValueException e){
+				} catch (InvalidValueException e){
 					throw e;
 				} catch (Exception e){
-					m_log.debug(e.getMessage(), e);
+					// 直前のgetMibValueDiff()の処理にて、failureValueが定義されていないpolling targetの場合に
+					// NullPointerExceptionが発生する。
+					// これはver4.0までの動作と同様のため、通常ルートではstacktraceを出力しないようにする。
+					m_log.debug("getDifferenceValue() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 					// エラー処理
 					throw new CollectedDataNotFoundException();
 				}
@@ -282,7 +244,11 @@ abstract public class Operator {
 				} catch (InvalidValueException e){
 					throw e;
 				} catch (Exception e){
-					m_log.debug(e.getMessage(), e);
+					// 直前のgetMibValueDiff()の処理にて、failureValueが定義されていないpolling targetの場合に
+					// NullPointerExceptionが発生する。
+					// これはver4.0までの動作と同様のため、通常ルートではstacktraceを出力しないようにする。
+					m_log.debug("getDifferenceValue() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 					// エラー処理
 					throw new CollectedDataNotFoundException();
 				}
@@ -294,16 +260,17 @@ abstract public class Operator {
 				String pollingTarget = data.getPollingTarget();
 
 				// 直近の取得時のデータテーブルからベースとなるpollingTarget配下の値全てを取得
-				Set<TableEntry> entrys = currentTable.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
+				Set<TableEntry> entries = currentTable.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
 
-				if(entrys == null){
+				if(entries == null){
+					m_log.info("getDifferenceValue() : entries is null");
 					// エラー処理
 					throw new CollectedDataNotFoundException();
 				}
 
 				// 合計を求める
 				double total = 0;  // 初期値0で初期化
-				Iterator<TableEntry> itr = entrys.iterator();
+				Iterator<TableEntry> itr = entries.iterator();
 				while(itr.hasNext()){
 					String tableEntryKey = itr.next().getKey();
 					total = total + getMibValueDiff(data, currentTable, previousTable, tableEntryKey, tableEntryKey);
@@ -311,11 +278,14 @@ abstract public class Operator {
 				}
 
 				return total;
+			} catch (CollectedDataNotFoundException e) {
+				throw e;
 			} catch (InvalidValueException e){
 				throw e;
 			} catch (Exception e){
 				// エラー処理
-				m_log.debug(e.getMessage(), e);
+				m_log.warn("getDifferenceValue() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				throw new CollectedDataNotFoundException();
 			}
 		} else {
@@ -326,34 +296,18 @@ abstract public class Operator {
 			} catch (InvalidValueException e){
 				throw e;
 			} catch (Exception e){
-				// エラー処理
-				m_log.debug(e.getMessage(), e);
+				// 直前のgetMibValueDiff()の処理にて、failureValueが定義されていないpolling targetの場合に
+				// NullPointerExceptionが発生する。
+				// これはver4.0までの動作と同様のため、通常ルートではstacktraceを出力しないようにする。
+				m_log.debug("getDifferenceValue() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				throw new CollectedDataNotFoundException();
 			}
 		}
 	}
 
-	/**
-	 * 全変数の前回収集時からの差分の合計を取得します。
-	 * @return 差分値
-	 */
-	protected double getDifferenceValueTotal()
-	throws CollectedDataNotFoundException, InvalidValueException {
-
-		Iterator<String> itr = getVariables().iterator();
-
-		double total = 0;
-		while(itr.hasNext()){
-			String variable = itr.next();
-
-			total = total + getDifferenceValue(variable);
-		}
-
-		return total;
-	}
-
-	protected double getValue(String variable, DataTable table)
-	throws CollectedDataNotFoundException, InvalidValueException{
+	private double getValue(String variable, DataTable table)
+			throws CollectedDataNotFoundException, InvalidValueException{
 		if(m_log.isDebugEnabled()){
 			m_log.debug("getValue() variable : " + variable);
 		}
@@ -438,7 +392,8 @@ abstract public class Operator {
 				} catch (CollectedDataNotFoundException e) {
 					throw e;
 				} catch (Exception e) {
-					m_log.error("getValue() Unknown Error", e);
+					m_log.warn("getValue() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				}
 
 				try {
@@ -447,7 +402,8 @@ abstract public class Operator {
 				catch (InvalidValueException e){
 					throw e;
 				} catch (Exception e){
-					m_log.debug(e.getMessage(), e);
+					m_log.warn("getValue() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 					// エラー処理
 					throw new CollectedDataNotFoundException();
 				}
@@ -469,7 +425,8 @@ abstract public class Operator {
 				} catch (InvalidValueException e){
 					throw e;
 				} catch (Exception e){
-					m_log.debug(e.getMessage(), e);
+					m_log.warn("getValue() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 					// エラー処理
 					throw new CollectedDataNotFoundException();
 				}
@@ -481,16 +438,17 @@ abstract public class Operator {
 				String pollingTarget = data.getPollingTarget();
 
 				// 直近の取得時のデータテーブルからベースとなるpollingTarget配下の値全てを取得
-				Set<TableEntry> entrys = table.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
+				Set<TableEntry> entries = table.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
 
-				if(entrys == null){
+				if(entries == null){
+					m_log.info("getValue() : entries is null");
 					// エラー処理
 					throw new CollectedDataNotFoundException();
 				}
 
 				// 合計を求める
 				double total = 0;  // 初期値0で初期化
-				Iterator<TableEntry> itr = entrys.iterator();
+				Iterator<TableEntry> itr = entries.iterator();
 				while(itr.hasNext()){
 					String tableEntryKey = itr.next().getKey();
 					total = total + getMibValueDouble(table, data, tableEntryKey);
@@ -498,9 +456,12 @@ abstract public class Operator {
 				}
 
 				return total;
+			} catch (CollectedDataNotFoundException e) {
+				throw e;
 			} catch (Exception e){
 				// エラー処理
-				m_log.debug(e.getMessage(), e);
+				m_log.warn("getValue() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				throw new CollectedDataNotFoundException();
 			}
 		} else {
@@ -510,7 +471,8 @@ abstract public class Operator {
 				throw e;
 			} catch (Exception e){
 				// エラー処理
-				m_log.debug(e.getMessage(), e);
+				m_log.warn("getValue() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				throw new CollectedDataNotFoundException();
 			}
 		}
@@ -600,7 +562,7 @@ abstract public class Operator {
 	 */
 	private double getMibValueDiff(CollectorPollingMstData data,
 			DataTable currentTable, DataTable previousTable, String currentEntryKey, String previousEntryKey)
-	throws InvalidValueException {
+					throws InvalidValueException {
 
 		// return用の変数
 		double ret = 0;
@@ -674,25 +636,32 @@ abstract public class Operator {
 				m_log.debug(getPlatformId() + ", " +  getItemCode() + ", " + variable);
 			}
 
-			CollectorPollingMstLocal bean = CollectorPollingMstUtil.getLocalHome()
-			.findByPrimaryKey(new CollectorPollingMstPK(getCollectMethod(), getPlatformId(), getSubPlatformId(), getItemCode(), variable));
+			CollectorPollingMstEntity bean = null;
+			try {
+				bean = QueryUtil.getCollectorPollingMstPK(getCollectMethod(),
+						getPlatformId(),
+						getSubPlatformId(),
+						getItemCode(),
+						variable);
+			} catch (CollectorNotFound e) {
+			}
+			if (bean != null) {
+				CollectorPollingMstData data = new CollectorPollingMstData(
+						bean.getId().getCollectMethod(),
+						bean.getId().getPlatformId(),
+						bean.getId().getSubPlatformId(),
+						bean.getId().getItemCode(),
+						bean.getId().getVariableId(),
+						bean.getEntryKey(),
+						bean.getSnmpValueTypeMstEntity().getValueType(),
+						bean.getPollingTarget(),
+						bean.getFailureValue());
 
-			CollectorPollingMstData data = new CollectorPollingMstData(
-					bean.getCollectMethod(),
-					bean.getPlatformId(),
-					bean.getSubPlatformId(),
-					bean.getItemCode(),
-					bean.getVariableId(),
-					bean.getEntryKey(),
-					bean.getValueType(),
-					bean.getPollingTarget(),
-					bean.getFailureValue());
-
-			m_oidMap.put(variable, data);
-		} catch (FinderException e) {
-			m_log.error(e.getMessage(), e);
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
+				m_oidMap.put(variable, data);
+			}
+		} catch (Exception e) {
+			m_log.warn("registerOidMap() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 	}
 
@@ -750,27 +719,24 @@ abstract public class Operator {
 
 		try{
 			// 収集項目コードから変数情報を取得する
-			Collection<CollectorPollingMstLocal> beans =
-				CollectorPollingMstUtil.getLocalHome().findByCollectMethodAndPlatformIdAndSubPlatformIdAndItemCode(
-						getCollectMethod(),
-						getPlatformId(),
-						getSubPlatformId(),
-						itemCode);
-
+			List<CollectorPollingMstEntity> beans =
+					QueryUtil.getAllCollectorPollingMstVariableId(getCollectMethod(),
+							getPlatformId(),
+							getSubPlatformId(),
+							itemCode);
 			// 保持している全ての変数IDをクリア
 			getVariables().clear();
 
 			// この収集項目で利用可能な変数IDをリストに保存
-			for(CollectorPollingMstLocal bean : beans){
+			for(CollectorPollingMstEntity bean : beans){
 				if(m_log.isDebugEnabled()){
-					m_log.debug("add " + bean.getVariableId());
+					m_log.debug("add " + bean.getId().getVariableId());
 				}
-				getVariables().add(bean.getVariableId());
+				getVariables().add(bean.getId().getVariableId());
 			}
-		} catch (FinderException e) {
-			m_log.error(e.getMessage(), e);
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
+		} catch (Exception e) {
+			m_log.warn("setItemCode() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 	}
 
@@ -797,4 +763,12 @@ abstract public class Operator {
 	public class CollectedDataNotFoundException extends Exception {
 		private static final long serialVersionUID = 6306555743811316089L;
 	}
+
+	public void setExpression(String expression) {
+		this.expression = expression;
+	}
+
+	public String getExpression() {
+		return expression;
+	}
 }
