@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Copyright (C) since 2006 NTT DATA Corporation
+# Copyright (C) 2013 NTT DATA Corporation
 # 
 # This program is free software; you can redistribute it and/or
 # Modify it under the terms of the GNU General Public License
@@ -51,15 +51,16 @@ echo "" | tee -a ${SUMMARY_FILE}
 HOST="localhost"
 PGPORT=24001
 LDAPPORT=24000
-PSQLBIN="${PG}/bin/psql"
 case ${VER_MJ} in
     '2.4')
+    PSQLBIN="${PG}/bin/psql"
     TABLE_COLLECTOR_PROFILE="collector_profile"
     TABLE_CALCULATED_DATA="calculated_data"
     COLUMN_COLLECTOR_PROFILE_INTERVAL="interval"
     VALUE_TRIGGER_NAME_PROCESS="PROCESS"
     ;;
     '3.0' | '3.1')
+    PSQLBIN="${PG}/bin/psql"
     PG_FACILITY="false"
     if [ `echo ${VER} | grep -E "3\.1\.[0-9]+\.L" | wc -l` -ne 0 ]
     then
@@ -72,13 +73,15 @@ case ${VER_MJ} in
     VALUE_TRIGGER_NAME_PROCESS="MON_PRC"
     ;;
     '3.2')
+    PSQLBIN="${PG}/bin/psql"
     PG_FACILITY="true"
     TABLE_COLLECTOR_PROFILE="cc_collector_profile"
     TABLE_CALCULATED_DATA="cc_calculated_data"
     COLUMN_COLLECTOR_PROFILE_INTERVAL="interval_sec"
     VALUE_TRIGGER_NAME_PROCESS="MON_PRC"
     ;;
-    '4.0')
+    '4.0' | '4.1')
+    PSQLBIN="${PG_HOME}/bin/psql"
     PG_FACILITY="true"
     TABLE_CALCULATED_DATA="cc_calculated_data"
     COLUMN_COLLECTOR_PROFILE_INTERVAL="interval_sec"
@@ -146,14 +149,18 @@ then
     fi
 fi
 
-echo -n "clustercontrolRepositoryUpdate: " | tee -a ${SUMMARY_FILE}
-${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 get "jboss.messaging.destination:service=Topic,name=clustercontrolRepositoryUpdate" AllSubscriptionsCount | tee -a ${SUMMARY_FILE}
-
-echo -n "clustercontrolJobManagementExecute: " | tee -a ${SUMMARY_FILE}
-${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 get "jboss.messaging.destination:service=Topic,name=clustercontrolJobManagementExecute" AllSubscriptionsCount | tee -a ${SUMMARY_FILE}
-
-echo -n "clustercontrolLogtransferUpdate: " | tee -a ${SUMMARY_FILE}
-${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 get "jboss.messaging.destination:service=Topic,name=clustercontrolLogtransferUpdate" AllSubscriptionsCount | tee -a ${SUMMARY_FILE}
+# if jboss is installed
+if [ -e ${JBOSS_HOME}/bin/twiddle.sh ]
+then
+	echo -n "clustercontrolRepositoryUpdate: " | tee -a ${SUMMARY_FILE}
+	${JBOSS_HOME}/bin/twiddle.sh -s jnp://127.0.0.1:1099 get "jboss.messaging.destination:service=Topic,name=clustercontrolRepositoryUpdate" AllSubscriptionsCount | tee -a ${SUMMARY_FILE}
+	
+	echo -n "clustercontrolJobManagementExecute: " | tee -a ${SUMMARY_FILE}
+	${JBOSS_HOME}/bin/twiddle.sh -s jnp://127.0.0.1:1099 get "jboss.messaging.destination:service=Topic,name=clustercontrolJobManagementExecute" AllSubscriptionsCount | tee -a ${SUMMARY_FILE}
+	
+	echo -n "clustercontrolLogtransferUpdate: " | tee -a ${SUMMARY_FILE}
+	${JBOSS_HOME}/bin/twiddle.sh -s jnp://127.0.0.1:1099 get "jboss.messaging.destination:service=Topic,name=clustercontrolLogtransferUpdate" AllSubscriptionsCount | tee -a ${SUMMARY_FILE}
+fi
 
 echo "" | tee -a ${SUMMARY_FILE}
 
@@ -203,7 +210,7 @@ ${PSQLCMD} -c "
 " | tee -a ${SUMMARY_FILE}
 
 ## "resource management" summary (collector_profile)
-if [ ${VER_MJ} != '4.0' ]; then
+if [ ${VER_MJ} != '4.0' ] && [ ${VER_MJ} != '4.1' ]; then
 echo "### collector_profile summary ###" | tee -a ${SUMMARY_FILE}
 ${PSQLCMD} -c "
     SELECT
@@ -229,7 +236,7 @@ ${PSQLCMD} -c "
 fi
 
 ## Syslog-ng/SNMPTrap filter count
-if [ ${VER_MJ} != '4.0' ]; then
+if [ ${VER_MJ} != '4.0' ] && [ ${VER_MJ} != '4.1' ]; then
 echo "### Syslog-ng/SNMP-TRAP filter summary ###" | tee -a ${SUMMARY_FILE}
 ${PSQLCMD} -c "
     SELECT
@@ -280,7 +287,7 @@ ${PSQLCMD} -c "
         cc_job_session s, cc_job_session_job j
     WHERE
         s.session_id = j.session_id AND s.jobunit_id = j.jobunit_id AND
-         s.job_id = j.job_id AND status NOT IN (300,301)
+         s.job_id = j.job_id AND status / 100 != 3
 " | tee -a ${SUMMARY_FILE}
 
 
@@ -366,15 +373,17 @@ then
     ${PSQLCMD} -c "
         SELECT
             platform_family,
-            virtualization_node_type,
-            virtualization_solution,
+            sub_platform_family,
+            vm_node_type,
+            cloud_node_type,
             count(*) count
         FROM
             cc_cfg_node
         GROUP BY
             platform_family,
-            virtualization_node_type,
-            virtualization_solution
+            sub_platform_family,
+            vm_node_type,
+            cloud_node_type
         ORDER BY
             count DESC;
     " | tee -a ${SUMMARY_FILE}
@@ -434,13 +443,6 @@ ${PSQLCMD} -c "
         idx_blks_read + idx_blks_hit DESC
 " | tee -a ${SUMMARY_FILE}
 
-## txid_current
-echo "### txid_current ###" | tee -a ${SUMMARY_FILE}
-${PSQLCMD} -c "
-    SELECT
-        txid_current()
-" | tee -a ${SUMMARY_FILE}
-
 
 
 }
@@ -548,15 +550,48 @@ echo "### lsof ###" | tee -a ${SUMMARY_FILE}
 lsof | tee -a ${SUMMARY_FILE}
 echo -e "\n" | tee -a ${SUMMARY_FILE}
 
-## twiddle.sh
-echo "### twiddle.sh ###" | tee -a ${SUMMARY_FILE}
-cd /tmp
-export JAVA_OPTS="-Xms16m -Xmx32m"
-${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 invoke "user:service=PollerService,name=PollerManager" printPollerInfo  | tee -a ${SUMMARY_FILE}
-${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 invoke "user:service=SharedTableService,name=SharedTable" printTableInfo | tee -a ${SUMMARY_FILE}
-${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 invoke "user:service=HinemosService,name=HinemosService" printSchedulerStatus | tee -a ${SUMMARY_FILE}
-${JBOSS_HOME}/bin/twiddle.sh -s jnp://${IP_ADDRESS}:1099 invoke "user:service=HinemosService,name=HinemosService" printSchedulerDetail | tee -a ${SUMMARY_FILE}
-echo -e "\n" | tee -a ${SUMMARY_FILE}
+if [ -e ${JBOSS_HOME}/bin/twiddle.sh ]
+then
+	## twiddle.sh
+	echo "### twiddle.sh ###" | tee -a ${SUMMARY_FILE}
+	cd /tmp
+	export JAVA_OPTS="-Xms16m -Xmx32m"
+	${JBOSS_HOME}/bin/twiddle.sh -s jnp://127.0.0.1:1099 invoke "user:service=PollerService,name=PollerManager" printPollerInfo  | tee -a ${SUMMARY_FILE}
+	${JBOSS_HOME}/bin/twiddle.sh -s jnp://127.0.0.1:1099 invoke "user:service=SharedTableService,name=SharedTable" printTableInfo | tee -a ${SUMMARY_FILE}
+	${JBOSS_HOME}/bin/twiddle.sh -s jnp://127.0.0.1:1099 invoke "user:service=HinemosService,name=HinemosService" printSchedulerStatus | tee -a ${SUMMARY_FILE}
+	${JBOSS_HOME}/bin/twiddle.sh -s jnp://127.0.0.1:1099 invoke "user:service=HinemosService,name=HinemosService" printSchedulerDetail | tee -a ${SUMMARY_FILE}
+	echo -e "\n" | tee -a ${SUMMARY_FILE}
+else
+	# manager_cli
+	echo "### manager_cli (Hinemos Agent Info) ###" | tee -a ${SUMMARY_FILE}
+	${HINEMOS_HOME}/sbin/manager_cli -c com.clustercontrol.commons.util.ManagerCliUtil -m getValidAgentStr | tee -a ${SUMMARY_FILE}
+	
+	echo "### manager_cli (Scheduler Info) ###" | tee -a ${SUMMARY_FILE}
+	${HINEMOS_HOME}/sbin/manager_cli -c com.clustercontrol.commons.util.ManagerCliUtil -m getSchedulerInfoStr | tee -a ${SUMMARY_FILE}
+	
+	echo "### manager_cli (Poller Info) ###" | tee -a ${SUMMARY_FILE}
+	${HINEMOS_HOME}/sbin/manager_cli -c com.clustercontrol.commons.util.ManagerCliUtil -m getPollerInfoStr | tee -a ${SUMMARY_FILE}
+	
+	echo "### manager_cli (SharedTable Info) ###" | tee -a ${SUMMARY_FILE}
+	${HINEMOS_HOME}/sbin/manager_cli -c com.clustercontrol.commons.util.ManagerCliUtil -m getSharedTableInfoStr | tee -a ${SUMMARY_FILE}
+	
+	echo "### manager_cli (SelfCheck LastFireTime) ###" | tee -a ${SUMMARY_FILE}
+	${HINEMOS_HOME}/sbin/manager_cli -c com.clustercontrol.commons.util.ManagerCliUtil -m getSelfCheckLastFireTimeStr | tee -a ${SUMMARY_FILE}
+	
+	echo "### manager_cli (AsynWorker Statistics) ###" | tee -a ${SUMMARY_FILE}
+	${HINEMOS_HOME}/sbin/manager_cli -c com.clustercontrol.commons.util.ManagerCliUtil -m getAsyncWorkerStatistics | tee -a ${SUMMARY_FILE}
+	
+	echo "### manager_cli (Syslog Statistics) ###" | tee -a ${SUMMARY_FILE}
+	${HINEMOS_HOME}/sbin/manager_cli -c com.clustercontrol.commons.util.ManagerCliUtil -m getSyslogStatistics | tee -a ${SUMMARY_FILE}
+	
+	echo "### manager_cli (SnmpTrap Statistics) ###" | tee -a ${SUMMARY_FILE}
+	${HINEMOS_HOME}/sbin/manager_cli -c com.clustercontrol.commons.util.ManagerCliUtil -m getSnmpTrapStatistics | tee -a ${SUMMARY_FILE}
+	
+	echo "### manager_cli (Job Queue Info) ###" | tee -a ${SUMMARY_FILE}
+	${HINEMOS_HOME}/sbin/manager_cli -c com.clustercontrol.commons.util.ManagerCliUtil -m getJobQueueStr | tee -a ${SUMMARY_FILE}
+	
+	echo -e "\n" | tee -a ${SUMMARY_FILE}
+fi
 
 ## md5sum
 echo "### md5sum ###" | tee -a ${SUMMARY_FILE}
